Extracted from https://www.pplelectric.com/at-your-service/for-generation-suppliers/general-supplier-reference-information/~/media/PPLElectric/At%20Your%20Service/Docs/General-Supplier-Reference-Information/2014LoadProfileEquations.txt